@@ -3,7 +3,7 @@
 # 
 # source file of the GNU LilyPond music typesetter
 #
-# (c) 1998--2006 Han-Wen Nienhuys <hanwen@xs4all.nl>
+# (c) 1998--2007 Han-Wen Nienhuys <hanwen@xs4all.nl>
 #                 Jan Nieuwenhuizen <janneke@gnu.org>
 
 import __main__
@@ -24,14 +24,14 @@ import optparse
 # it as we do with teTeX on Red Hat Linux: set some environment var
 # (PYTHONPATH) in profile)
 
-# If set, LILYPONDPREFIX must take prevalence
-# if datadir is not set, we're doing a build and LILYPONDPREFIX
+# If set, LILYPOND_DATADIR must take prevalence
+# if datadir is not set, we're doing a build and LILYPOND_DATADIR
 
-datadir = '/usr/share/lilypond/2.10.0'
+datadir = '/usr/share/lilypond/2.10.33'
 if not os.path.isdir (datadir):
-    datadir = '/usr/share/lilypond/2.10.0'
-if os.environ.has_key ('LILYPONDPREFIX') :
-    datadir = os.environ['LILYPONDPREFIX']
+    datadir = '/usr/share/lilypond/2.10.33'
+if os.environ.has_key ('LILYPOND_DATADIR') :
+    datadir = os.environ['LILYPOND_DATADIR']
     while datadir[-1] == os.sep:
 	datadir= datadir[:-1]
 
